@@ -112,7 +112,6 @@ static void
 set_lang (void)
 {
   const char *gdm_lang;
-  char       *env_string;
   char       *short_lang;
   char       *p;
 
@@ -124,14 +123,10 @@ set_lang (void)
       if (p)
 	*p = '\0';
 
-      env_string = g_strconcat ("LANG=", gdm_lang, NULL);
-      putenv (env_string);
+      g_setenv ("LANG", gdm_lang, TRUE);
 
-      /* env_string = g_strconcat ("LANGUAGE=", short_lang, NULL);
-      putenv (env_string); */
-
-      /* env_string = g_strconcat ("LC_ALL=", gdm_lang, NULL);
-      putenv (env_string); */
+      /* g_setenv ("LANGUAGE", short_lang, TRUE); */
+      /* g_setenv ("LC_ALL", gdm_lang, TRUE); */
 
       g_free (short_lang);
     }
@@ -323,7 +318,7 @@ is_later_than_date_of_doom (void)
   t = time (NULL);
   tm = localtime (&t);
 
-  return (tm->tm_year >= 106); /* We start on Jan 1 2006 */
+  return (tm->tm_year >= 105); /* We start on Jan 1 2006 */
 }
 
 int
@@ -395,6 +390,14 @@ main (int argc, char *argv[])
         }
     }
   
+  /* Read the config option early, so that we know if a11y is set or not */ 
+  gconf_client = gconf_client_get_default ();
+  gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL); 
+  a_t_support = gconf_client_get_bool (gconf_client, ACCESSIBILITY_KEY, NULL);
+
+  if (a_t_support)
+    gsm_at_set_gtk_modules ();
+
   gnome_program_init("gnome-session", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
 		  GNOME_PARAM_POPT_TABLE, options,
 		  NULL);
@@ -424,11 +427,10 @@ main (int argc, char *argv[])
 
   /* Need DISPLAY set */
   gsm_keyring_daemon_start ();
+  gsm_gsd_start ();
   
-  /* Read in config options */  
-  gconf_client = gconf_client_get_default ();
+  /* Read the rest of config options */  
 
-  gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
   splashing      = gconf_client_get_bool (gconf_client, SPLASH_SCREEN_KEY, NULL);
   autosave       = gconf_client_get_bool (gconf_client, AUTOSAVE_MODE_KEY, NULL);
   logout_prompt  = gconf_client_get_bool (gconf_client, LOGOUT_PROMPT_KEY, NULL);
@@ -478,8 +480,6 @@ main (int argc, char *argv[])
 
   gsm_sound_login ();
 
-  gsm_gsd_start ();
-
   gsm_remote_desktop_start ();
 
   if (splashing)
